from logging import Logger
from requests.sessions import Session


def netflix_download(_session: Session, _logger: Logger):
    """
    This does the downloads
    :param session:
    :param logger:
    :return:
    """
    # url = "netflix.com/xxxx"
